@@ -99,7 +99,7 @@ bbt_run_from_model <- function(
   babette::prepare_file_creation(inference_model, beast2_options)
 
   beastier::check_beast2_path(beast2_options$beast2_path)
-  check_beast2_pkgs(
+  babette::check_beast2_pkgs(
     mcmc = inference_model$mcmc,
     beast2_path = beast2_options$beast2_path
   )
